---
license: bsd-3-clause
---

# Iris Classification
This repository contains the generated `onnx` and `pytorch` model files for the 
[Iris Classification](https://github.com/ritual-net/simple-ml-models/blob/main/iris_classification/README.md) project, 
which is a simple project used in our tutorials & docs. 

Refer to the [`simple-ml-models`](https://github.com/ritual-net/simple-ml-models) repository for more information.